@@ -1,6 +1,6 @@
 context("random.dag")
 
-test_that("random.dag runs as expected", {
+test_that("random.dag runs as expected", { # PASSES
     expect_error(random.dag(1,1), "A DAG with p = 1")
     expect_error(random.dag(2,2), "A DAG with p = 2")
 
@@ -27,7 +27,7 @@ test_that("random.dag runs as expected", {
     expect_error(random.dag(10,10,function(n) rgamma(n, shape = 10)), NA)
 })
 
-test_that("random.dag always produces a DAG", {
+test_that("random.dag always produces a DAG", { # PASSES
     ### This test requires the igraph pkg
     if(requireNamespace("igraph", quietly = TRUE)){
         m <- random.dag(5,5)
@@ -35,3 +35,24 @@ test_that("random.dag always produces a DAG", {
         expect_warning(igraph::topo_sort(igraph::graph.adjacency(m)), NA)
     }
 })
+
+test_that("random.dag works in degenerate cases", { # FAILS
+    # Null graphs
+    expect_error(random.dag(1, 0), NA) # FAILS
+    expect_error(random.dag(2, 0), NA) # PASSES
+    expect_error(random.dag(3, 0), NA) # PASSES
+    expect_error(random.dag(5, 0), NA) # PASSES
+
+    # One edge
+    ### nnode = 1 can't have any edges
+    expect_error(random.dag(2, 1), NA) # PASSES
+    expect_error(random.dag(3, 1), NA) # PASSES
+    expect_error(random.dag(5, 1), NA) # PASSES
+
+    # Max edges
+    expect_error(random.dag(1, 0), NA) # FAILS
+    expect_error(random.dag(2, 1), NA) # PASSES
+    expect_error(random.dag(3, 3), NA) # PASSES
+    expect_error(random.dag(5, 10), NA) # PASSES
+})
+
